Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/pytest_vulture/__init__.py | VultureError | 2 | 2 | 3 | 0 | 0 | 0.00%
src/pytest_vulture/conf/base.py | Configuration | 6 | 2 | 0 | 0 | 0 | 66.67%
src/pytest_vulture/conf/package.py | PackageConfiguration | 14 | 5 | 4 | 0 | 0 | 64.29%
src/pytest_vulture/conf/reader.py | IniReader | 17 | 5 | 0 | 4 | 1 | 71.43%
src/pytest_vulture/conf/vulture.py | VultureConfiguration | 27 | 6 | 2 | 0 | 0 | 77.78%
src/pytest_vulture/setup_manager.py | SetupManager | 86 | 25 | 4 | 32 | 9 | 67.80%
src/pytest_vulture/vulture/manager.py | VultureManager | 27 | 16 | 0 | 12 | 1 | 30.77%
Total |  | 309 | 61 | 20 | 48 | 11 | 75.91%

No items found using the specified filter.

7 classes skipped due to complete coverage.